@@ -5,7 +5,7 @@ use vars qw/$VERSION/;
 use Scalar::Util qw/reftype weaken/;
 use Carp;
 use SUPER;
-$VERSION = '0.15';
+$VERSION = '0.16';
 
 my %mocked;
 sub new {
@@ -157,8 +157,10 @@ sub _valid_subname {
 
 sub _replace_sub {
 	my ($sub_name, $coderef) = @_;
-	# from Test::MockObject
-	local $SIG{__WARN__} = sub { warn $_[0] unless $_[0] =~ /redefined/ };
+
+    no warnings 'redefine';
+    no warnings 'prototype';
+
 	if (defined $coderef) {
 		*{$sub_name} = $coderef;
 	} else {
@@ -300,7 +302,7 @@ instance).
 B<MOCKING + EXPORT>
 
 If you are trying to mock a subroutine exported from another module, this may
-not behave as you initialy would expect, since Test::MockModule is only mocking
+not behave as you initially would expect, since Test::MockModule is only mocking
 at the target module, not anything importing that module. If you mock the local
 package, or use a fully qualified function name, you will get the behavior you
 desire:
@@ -338,11 +340,11 @@ you can instead mock it in the module you are testing:
 	my $posix = Test::MockModule->new("POSIX");
 	$posix->mock("strftime", "Yesterday");
 
-	is MyModule::minus_twentyfour(), "Yesterday", "`minus-tewntyfour` got mocked"; # fails
+	is MyModule::minus_twentyfour(), "Yesterday", "`minus-twentyfour` got mocked"; # fails
 
 	my $mymodule = Test::MockModule->new("MyModule", no_auto => 1);
 	$mymodule->mock("strftime", "Yesterday");
-	is MyModule::minus_twentyfour(), "Yesterday", "`minus-tewntyfour` got mocked"; # succeeds
+	is MyModule::minus_twentyfour(), "Yesterday", "`minus-twentyfour` got mocked"; # succeeds
 
 =item redefine($subroutine)
 
